@@ -266,19 +266,19 @@ class Transformer:
             else:
                 return False, None
 
-        elif schema.get("format") == "date-time":
+        elif typ == "string" and schema.get("format") == "date-time":
             data = self._transform_datetime(data)
             if data is None:
                 return False, None
 
             return True, data
-        elif schema.get("format") == "singer.decimal":
+        elif typ == "string" and schema.get("format") == "singer.decimal":
             if data is None:
                 return False, None
 
             if isinstance(data, (str, float, int)):
                 try:
-                    return True, str(decimal.Decimal(str(data)).normalize())
+                    return True, str(decimal.Decimal(str(data)))
                 except:
                     return False, None
             elif isinstance(data, decimal.Decimal):
@@ -286,7 +286,7 @@ class Transformer:
                     if data.is_snan():
                         return True, 'NaN'
                     else:
-                        return True, str(data.normalize())
+                        return True, str(data)
                 except:
                     return False, None
 
